All Classes and Interfaces

Class
Description
You don't have access to perform this operation on this resource.
 
Describes an additional authentication provider.
 
Describes an AppSync API.
 
Describes an ApiAssociation object.
 
The ApiCache object.
 
 
 
 
Describes an API key.
 
The API key exceeded a limit.
 
The API key expiration must be set to a value between 1 and 365 days from creation (for CreateApiKey) or from update (for UpdateApiKey).
 
The GraphQL API exceeded a limit.
 
Service client for accessing AWSAppSync asynchronously.
A builder for creating an instance of AppSyncAsyncClient.
 
The parameters object used to resolve the auth schemes for the AppSync service.
A builder for a AppSyncAuthSchemeParams.
An auth scheme provider for AppSync service.
This includes configuration specific to AWSAppSync that is supported by both AppSyncClientBuilder and AppSyncAsyncClientBuilder.
Service client for accessing AWSAppSync.
A builder for creating an instance of AppSyncClient.
 
The parameters object used to resolve an endpoint for the AppSync service.
 
An endpoint provider for AppSync.
 
 
 
 
 
 
 
 
 
 
 
 
Describes a runtime used by an Amazon Web Services AppSync pipeline resolver or Amazon Web Services AppSync function.
 
Class to expose the service client settings to the user.
A builder for creating a AppSyncServiceClientConfiguration
 
An AWS Arn.
 
 
 
 
 
 
 
 
 
 
 
 
 
 
Describes an authorization configuration.
 
The authorization configuration in case the HTTP endpoint requires authorization.
 
 
Describes an authorization provider.
 
 
The Identity and Access Management (IAM) configuration.
 
Provides further details for the reason behind the bad request.
 
The request is not well formed.
 
Provides context for the cause of the bad request.
 
The caching configuration for a resolver that has caching activated.
 
Describes a channel namespace associated with an Api.
 
Describes an AppSync error.
 
Describes the location of the error in a code sample.
 
Describes an Amazon Cognito configuration.
 
Describes an Amazon Cognito user pool configuration.
 
Another modification is in progress at this time and it must complete before you can make your change.
 
 
A conflict with a previous successful update is detected.
 
 
Represents the input of a CreateApiCache operation.
 
Represents the output of a CreateApiCache operation.
 
 
 
 
 
 
 
CreateApiRequest Marshaller
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
Describes a data source.
 
Contains the introspected data that was retrieved from the data source.
 
Represents the fields that were retrieved from the introspected data.
 
Represents the type data for each field retrieved from the introspection.
 
The index that was retrieved from the introspected data.
 
Represents the output of a DataSourceIntrospectionResult.
 
 
 
 
 
 
 
 
 
 
 
Represents the input of a DeleteApiCache operation.
 
Represents the output of a DeleteApiCache operation.
 
 
 
 
 
 
 
DeleteApiRequest Marshaller
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
Describes a Delta Sync configuration.
 
 
 
 
 
 
 
 
 
 
 
 
 
Describes a configuration for a custom domain.
 
Describes an Amazon DynamoDB data source configuration.
 
Describes an OpenSearch data source configuration.
 
Link between an endpoint property and the AwsEndpointAttribute it represents.
 
 
Enables and controls the enhanced metrics feature.
 
Contains the list of errors generated.
 
Contains the list of errors from a code evaluation response.
 
 
 
 
 
 
 
 
 
Describes an Amazon EventBridge bus data source configuration.
 
Describes the authorization configuration for connections, message publishing, message subscriptions, and logging for an Event API.
 
Describes the CloudWatch Logs configuration for the Event API.
 
 
 
Represents the input of a FlushApiCache operation.
 
Represents the output of a FlushApiCache operation.
 
A function is a reusable entity.
 
 
 
 
 
Represents the input of a GetApiCache operation.
 
Represents the output of a GetApiCache operation.
 
 
 
GetApiRequest Marshaller
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
GetTypeRequest Marshaller
 
 
Describes a GraphQL API.
 
 
 
 
The GraphQL schema is not valid.
 
 
The configuration for a handler.
 
The configuration for the OnPublish and OnSubscribe handlers.
 
Describes an HTTP data source configuration.
 
Identifiers for variables declared within the rule engine, e.g.
The integration data source configuration for the handler.
 
An internal AppSync error occurred.
 
 
A LambdaAuthorizerConfig specifies how to authorize AppSync API access when using the AWS_LAMBDA authorizer mode.
 
The configuration for a Lambda data source.
 
The LambdaConflictHandlerConfig object when configuring LAMBDA as the Conflict Handler.
 
Describes an Lambda data source configuration.
 
The request exceeded a limit.
 
Represents the output for the AppSyncClient.listApiKeysPaginator(software.amazon.awssdk.services.appsync.model.ListApiKeysRequest) operation which is a paginated operation.
Represents the output for the AppSyncAsyncClient.listApiKeysPaginator(software.amazon.awssdk.services.appsync.model.ListApiKeysRequest) operation which is a paginated operation.
 
 
 
 
Represents the output for the AppSyncClient.listApisPaginator(software.amazon.awssdk.services.appsync.model.ListApisRequest) operation which is a paginated operation.
Represents the output for the AppSyncAsyncClient.listApisPaginator(software.amazon.awssdk.services.appsync.model.ListApisRequest) operation which is a paginated operation.
 
 
ListApisRequest Marshaller
 
 
 
 
 
 
Represents the output for the AppSyncClient.listDataSourcesPaginator(software.amazon.awssdk.services.appsync.model.ListDataSourcesRequest) operation which is a paginated operation.
 
 
 
 
Represents the output for the AppSyncClient.listDomainNamesPaginator(software.amazon.awssdk.services.appsync.model.ListDomainNamesRequest) operation which is a paginated operation.
 
 
 
 
Represents the output for the AppSyncClient.listFunctionsPaginator(software.amazon.awssdk.services.appsync.model.ListFunctionsRequest) operation which is a paginated operation.
Represents the output for the AppSyncAsyncClient.listFunctionsPaginator(software.amazon.awssdk.services.appsync.model.ListFunctionsRequest) operation which is a paginated operation.
 
 
 
 
Represents the output for the AppSyncClient.listGraphqlApisPaginator(software.amazon.awssdk.services.appsync.model.ListGraphqlApisRequest) operation which is a paginated operation.
 
 
 
 
 
 
 
 
Represents the output for the AppSyncClient.listResolversPaginator(software.amazon.awssdk.services.appsync.model.ListResolversRequest) operation which is a paginated operation.
Represents the output for the AppSyncAsyncClient.listResolversPaginator(software.amazon.awssdk.services.appsync.model.ListResolversRequest) operation which is a paginated operation.
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
Represents the output for the AppSyncClient.listTypesPaginator(software.amazon.awssdk.services.appsync.model.ListTypesRequest) operation which is a paginated operation.
Represents the output for the AppSyncAsyncClient.listTypesPaginator(software.amazon.awssdk.services.appsync.model.ListTypesRequest) operation which is a paginated operation.
 
 
ListTypesRequest Marshaller
 
 
The Amazon CloudWatch Logs configuration.
 
 
The resource specified in the request was not found.
 
Describes an OpenID Connect (OIDC) configuration.
 
Describes an OpenSearch data source configuration.
 
 
 
 
 
 
 
 
 
 
 
The pipeline configuration for a resolver of kind PIPELINE.
 
 
 
 
 
 
Contains the metadata required to introspect the RDS cluster.
 
The Amazon Relational Database Service (Amazon RDS) HTTP endpoint configuration.
 
 
 
Describes a relational database data source configuration.
 
 
Describes a resolver.
 
 
 
 
 
 
 
 
 
Represents a URL to be used internally for endpoint resolution.
 
 
The operation exceeded the service quota for this resource.
 
 
Describes the configuration of a source API.
 
Describes properties used to specify configurations related to a source API.
 
 
Describes the ARNs and IDs of associations, Merged APIs, and source APIs.
 
 
 
 
 
 
 
 
 
 
 
 
 
Describes a Sync configuration for a resolver.
 
 
 
 
 
Describes a type.
 
 
You aren't authorized to perform this operation.
 
 
 
 
 
Represents the input of a UpdateApiCache operation.
 
Represents the output of a UpdateApiCache operation.
 
 
 
 
 
 
 
UpdateApiRequest Marshaller
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
Describes an Amazon Cognito user pool configuration.
 
Base class for the types of values computable by the RuleEngine.
An array value.
A boolean value.
 
 
An integer value.
 
A record (map) value.
A string value.