Constant Field Values
Contents
software.amazon.*
-
software.amazon.awssdk.services.appsync.AppSyncAsyncClient Modifier and Type Constant Field Value public static final StringSERVICE_METADATA_ID"appsync"public static final StringSERVICE_NAME"appsync" -
software.amazon.awssdk.services.appsync.AppSyncClient Modifier and Type Constant Field Value public static final StringSERVICE_METADATA_ID"appsync"public static final StringSERVICE_NAME"appsync"
-
software.amazon.awssdk.services.appsync.internal.ServiceVersionInfo Modifier and Type Constant Field Value public static final StringVERSION"2.42.x"