Class DataSourceIntrospectionModelField
java.lang.Object
software.amazon.awssdk.services.appsync.model.DataSourceIntrospectionModelField
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<DataSourceIntrospectionModelField.Builder,DataSourceIntrospectionModelField>
@Generated("software.amazon.awssdk:codegen")
public final class DataSourceIntrospectionModelField
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<DataSourceIntrospectionModelField.Builder,DataSourceIntrospectionModelField>
Represents the fields that were retrieved from the introspected data.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Longlength()The length value of the introspected field.final Stringname()The name of the field that was retrieved from the introspected data.static Class<? extends DataSourceIntrospectionModelField.Builder>final StringtoString()Returns a string representation of this object.type()TheDataSourceIntrospectionModelFieldTypeobject data.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
name
The name of the field that was retrieved from the introspected data.
- Returns:
- The name of the field that was retrieved from the introspected data.
-
type
The
DataSourceIntrospectionModelFieldTypeobject data.- Returns:
- The
DataSourceIntrospectionModelFieldTypeobject data.
-
length
The length value of the introspected field.
- Returns:
- The length value of the introspected field.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<DataSourceIntrospectionModelField.Builder,DataSourceIntrospectionModelField>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-