Class EvaluateCodeRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<EvaluateCodeRequest.Builder,EvaluateCodeRequest>

@Generated("software.amazon.awssdk:codegen") public final class EvaluateCodeRequest extends AppSyncRequest implements ToCopyableBuilder<EvaluateCodeRequest.Builder,EvaluateCodeRequest>
  • Method Details

    • runtime

      public final AppSyncRuntime runtime()

      The runtime to be used when evaluating the code. Currently, only the APPSYNC_JS runtime is supported.

      Returns:
      The runtime to be used when evaluating the code. Currently, only the APPSYNC_JS runtime is supported.
    • code

      public final String code()

      The code definition to be evaluated. Note that code and runtime are both required for this action. The runtime value must be APPSYNC_JS.

      Returns:
      The code definition to be evaluated. Note that code and runtime are both required for this action. The runtime value must be APPSYNC_JS.
    • context

      public final String context()

      The map that holds all of the contextual information for your resolver invocation. A context is required for this action.

      Returns:
      The map that holds all of the contextual information for your resolver invocation. A context is required for this action.
    • function

      public final String function()

      The function within the code to be evaluated. If provided, the valid values are request and response.

      Returns:
      The function within the code to be evaluated. If provided, the valid values are request and response.
    • toBuilder

      public EvaluateCodeRequest.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<EvaluateCodeRequest.Builder,EvaluateCodeRequest>
      Specified by:
      toBuilder in class AppSyncRequest
    • builder

      public static EvaluateCodeRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends EvaluateCodeRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo