Class HttpDataSourceConfig
java.lang.Object
software.amazon.awssdk.services.appsync.model.HttpDataSourceConfig
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<HttpDataSourceConfig.Builder,HttpDataSourceConfig>
@Generated("software.amazon.awssdk:codegen")
public final class HttpDataSourceConfig
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<HttpDataSourceConfig.Builder,HttpDataSourceConfig>
Describes an HTTP data source configuration.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal AuthorizationConfigThe authorization configuration in case the HTTP endpoint requires authorization.static HttpDataSourceConfig.Builderbuilder()final Stringendpoint()The HTTP URL endpoint.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends HttpDataSourceConfig.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
endpoint
The HTTP URL endpoint. You can specify either the domain name or IP, and port combination, and the URL scheme must be HTTP or HTTPS. If you don't specify the port, AppSync uses the default port 80 for the HTTP endpoint and port 443 for HTTPS endpoints.
- Returns:
- The HTTP URL endpoint. You can specify either the domain name or IP, and port combination, and the URL scheme must be HTTP or HTTPS. If you don't specify the port, AppSync uses the default port 80 for the HTTP endpoint and port 443 for HTTPS endpoints.
-
authorizationConfig
The authorization configuration in case the HTTP endpoint requires authorization.
- Returns:
- The authorization configuration in case the HTTP endpoint requires authorization.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<HttpDataSourceConfig.Builder,HttpDataSourceConfig>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-