Class ListChannelNamespacesRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.appsync.model.AppSyncRequest
software.amazon.awssdk.services.appsync.model.ListChannelNamespacesRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<ListChannelNamespacesRequest.Builder,ListChannelNamespacesRequest>
@Generated("software.amazon.awssdk:codegen")
public final class ListChannelNamespacesRequest
extends AppSyncRequest
implements ToCopyableBuilder<ListChannelNamespacesRequest.Builder,ListChannelNamespacesRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringapiId()TheApiID.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final IntegerThe maximum number of results that you want the request to return.final StringAn identifier that was returned from the previous call to this operation, which you can use to return the next set of items in the list.static Class<? extends ListChannelNamespacesRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
apiId
The
ApiID.- Returns:
- The
ApiID.
-
nextToken
An identifier that was returned from the previous call to this operation, which you can use to return the next set of items in the list.
- Returns:
- An identifier that was returned from the previous call to this operation, which you can use to return the next set of items in the list.
-
maxResults
The maximum number of results that you want the request to return.
- Returns:
- The maximum number of results that you want the request to return.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ListChannelNamespacesRequest.Builder,ListChannelNamespacesRequest> - Specified by:
toBuilderin classAppSyncRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-