Class UserPoolConfig
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<UserPoolConfig.Builder,UserPoolConfig>
Describes an Amazon Cognito user pool configuration.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringA regular expression for validating the incoming Amazon Cognito user pool app client ID.final StringThe Amazon Web Services Region in which the user pool was created.static UserPoolConfig.Builderbuilder()final DefaultActionThe action that you want your GraphQL API to take when a request that uses Amazon Cognito user pool authentication doesn't match the Amazon Cognito user pool configuration.final StringThe action that you want your GraphQL API to take when a request that uses Amazon Cognito user pool authentication doesn't match the Amazon Cognito user pool configuration.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends UserPoolConfig.Builder>final StringtoString()Returns a string representation of this object.final StringThe user pool ID.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
userPoolId
The user pool ID.
- Returns:
- The user pool ID.
-
awsRegion
The Amazon Web Services Region in which the user pool was created.
- Returns:
- The Amazon Web Services Region in which the user pool was created.
-
defaultAction
The action that you want your GraphQL API to take when a request that uses Amazon Cognito user pool authentication doesn't match the Amazon Cognito user pool configuration.
If the service returns an enum value that is not available in the current SDK version,
defaultActionwill returnDefaultAction.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromdefaultActionAsString().- Returns:
- The action that you want your GraphQL API to take when a request that uses Amazon Cognito user pool authentication doesn't match the Amazon Cognito user pool configuration.
- See Also:
-
defaultActionAsString
The action that you want your GraphQL API to take when a request that uses Amazon Cognito user pool authentication doesn't match the Amazon Cognito user pool configuration.
If the service returns an enum value that is not available in the current SDK version,
defaultActionwill returnDefaultAction.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromdefaultActionAsString().- Returns:
- The action that you want your GraphQL API to take when a request that uses Amazon Cognito user pool authentication doesn't match the Amazon Cognito user pool configuration.
- See Also:
-
appIdClientRegex
A regular expression for validating the incoming Amazon Cognito user pool app client ID. If this value isn't set, no filtering is applied.
- Returns:
- A regular expression for validating the incoming Amazon Cognito user pool app client ID. If this value isn't set, no filtering is applied.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<UserPoolConfig.Builder,UserPoolConfig>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-