Class EvaluateCodeRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.appsync.model.AppSyncRequest
software.amazon.awssdk.services.appsync.model.EvaluateCodeRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<EvaluateCodeRequest.Builder,EvaluateCodeRequest>
@Generated("software.amazon.awssdk:codegen")
public final class EvaluateCodeRequest
extends AppSyncRequest
implements ToCopyableBuilder<EvaluateCodeRequest.Builder,EvaluateCodeRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic EvaluateCodeRequest.Builderbuilder()final Stringcode()The code definition to be evaluated.final Stringcontext()The map that holds all of the contextual information for your resolver invocation.final booleanfinal booleanequalsBySdkFields(Object obj) final Stringfunction()The function within the code to be evaluated.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final AppSyncRuntimeruntime()The runtime to be used when evaluating the code.static Class<? extends EvaluateCodeRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
runtime
The runtime to be used when evaluating the code. Currently, only the
APPSYNC_JSruntime is supported.- Returns:
- The runtime to be used when evaluating the code. Currently, only the
APPSYNC_JSruntime is supported.
-
code
The code definition to be evaluated. Note that
codeandruntimeare both required for this action. Theruntimevalue must beAPPSYNC_JS.- Returns:
- The code definition to be evaluated. Note that
codeandruntimeare both required for this action. Theruntimevalue must beAPPSYNC_JS.
-
context
The map that holds all of the contextual information for your resolver invocation. A
contextis required for this action.- Returns:
- The map that holds all of the contextual information for your resolver invocation. A
contextis required for this action.
-
function
The function within the code to be evaluated. If provided, the valid values are
requestandresponse.- Returns:
- The function within the code to be evaluated. If provided, the valid values are
requestandresponse.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<EvaluateCodeRequest.Builder,EvaluateCodeRequest> - Specified by:
toBuilderin classAppSyncRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-